%bcond_without tests

%define	major		10
%define major_cpp	16
%define major_f		10

%define major_hl	10
%define major_hl_cpp	11
%define major_hl_f	10

%define libname		%mklibname hdf5_ %{major}
%define libname_cpp     %mklibname hdf5_cpp %{major_cpp}
%define libname_f	%mklibname hdf5_fortran %{major_f}

%define libname_hl	%mklibname hdf5_hl %{major_hl}
%define libname_hl_cpp	%mklibname hdf5_hl_cpp %{major_hl_cpp}
# Technically wrongly named, but be consistent with other lib names
%define libname_hl_f	%mklibname hdf5_hl_fortran %{major_hl_f}

%define develname	%mklibname %{name} -d

#define patchlevel -patch1

Name:		hdf5_10
Version:	1.8.21
Release:	%mkrel 8
Summary:	HDF5 library
License:	Distributable (see included COPYING)
Group:		System/Libraries
URL:		https://www.hdfgroup.org/HDF5/
Source0:	https://support.hdfgroup.org/ftp/HDF5/releases/hdf5-1.8/hdf5-%{version}/src/hdf5-%{version}%{?patchlevel}.tar.bz2#/%{name}-%{version}%{?patchlevel}.tar.bz2
Patch0:		hdf5-LD_LIBRARY_PATH.patch
# Properly run MPI_Finalize() in t_pflush1
Patch1:		hdf5-mpi.patch
# Fix compilation with -Werror=implicit-function-declaration
Patch2:		hdf5-implicit.patch
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(krb5)
BuildRequires:	gcc-gfortran

# mga6 provides hdf5 1.8 as hdf5
Obsoletes:	hdf5 < 1.8.21-4

# mga7 provides also newer hdf5 1.10
Conflicts:	hdf5 >= 1.10.4

%description
HDF5 is a library and file format for storing scientific data. It was
designed to address some of the limitations of the HDF 4.x library and to
address current and anticipated requirements of modern systems and
applications. HDF5 includes the following improvements.

   - A new file format designed to address some of the deficiencies of
     HDF4.x, particularly the need to store larger files and more
     objects per file.
   - A simpler, more comprehensive data model that includes only two
     basic structures: a multidimensional array of record structures,
     and a grouping structure.
   - A simpler, better-engineered library and API, with improved
     support for parallel i/o, threads, and other requirements imposed
     by modern systems and applications.

%package -n %{libname}
Summary:	HDF5 libraries
Group:		System/Libraries
Provides:	lib%{name} = %{version}-%{release}
Obsoletes:	%{_lib}hdf5_10_10 < 1.8.21-4

%description -n %{libname}
This package contains the libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{libname_cpp}
Summary:        HDF5 libraries
Group:          System/Libraries
Provides:	lib%{name}_cpp = %{version}-%{release}
Obsoletes:      %{_lib}hdf5_10_cpp16 < 1.8.21-4

%description -n %{libname_cpp}
This package contains the libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{libname_f}
Summary:        HDF5 libraries
Group:          System/Libraries
Provides:	lib%{name}_cpp = %{version}-%{release}
Conflicts:	%{_lib}hdf5_10 < 1.8.21-5

%description -n %{libname_f}
This package contains the libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{libname_hl}
Summary:	HDF5 high level libraries
Group:		System/Libraries
Provides:	lib%{name}_hl = %{version}-%{release}
Obsoletes:	%{_lib}hdf5_10_hl10 < 1.8.21-4

%description -n %{libname_hl}
This package contains the high level libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{libname_hl_cpp}
Summary:	HDF5 high level libraries
Group:		System/Libraries
Provides:	lib%{name}_hl_cpp = %{version}-%{release}
Obsoletes:	%{_lib}hdf5_10_hl_cpp11 < 1.8.21-4

%description -n %{libname_hl_cpp}
This package contains the high level libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{libname_hl_f}
Summary:	HDF5 high level libraries
Group:		System/Libraries
Conflicts:	%{_lib}hdf5_hl10 < 1.8.21-4

%description -n %{libname_hl_f}
This package contains the high level libraries needed to run programs dynamically
linked with hdf5 libraries.

%package -n %{develname}
Summary:	Development libraries and header files for hdf5 development
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_cpp} = %{version}-%{release}
Requires:	%{libname_f} = %{version}-%{release}
Requires:	%{libname_hl} = %{version}-%{release}
Requires:	%{libname_hl_cpp} = %{version}-%{release}
Requires:	%{libname_hl_f} = %{version}-%{release}
Obsoletes:	%{_lib}hdf5-devel < 1.8.21-4
Conflicts:	%{_lib}hdf5-devel >= 1.10.4-1

%description -n %{develname}
This package provides static libraries and header files needed
for develop applications requiring the "hdf5" library.

%prep
%autosetup -p1 -n hdf5-%{version}%{?patchlevel}
find -name '*.[ch]' -o -name '*.f90' -exec chmod -x {} +

find %{buildroot} -type f -size 0 -name Dependencies -print0 |xargs -0 rm -f
find %{buildroot} -type f -size 0 -name .depend -print0 |xargs -0 rm -f

%build
# fix build on aarch64
autoreconf -vfi

OPT_FLAGS="%{optflags} -O1 -Wno-long-long -Wfloat-equal -Wmissing-format-attribute -Wpadded"
%ifarch %{ix86} x86_64
OPT_FLAGS="$OPT_FLAGS -mieee-fp"
%endif

# (gb) 1.4.2-2mdk: "2.96" still deficient wrt. C++ exception handling on ia32
%ifarch %ix86
OPT_FLAGS=`echo "$OPT_FLAGS -fno-omit-frame-pointer" | sed -e "s/-fomit-frame-pointer//g"`
%endif

# (gb) 1.4.2-2mdk: constants merging causes troubles with long doubles on ia64
%ifarch ia64
OPT_FLAGS="$OPT_FLAGS -fno-merge-constants"
%endif

%ifarch x86_64
OPT_FLAGS="$OPT_FLAGS -fPIC"
%endif

#(tpg) disable all strange flags
#CFLAGS="$OPT_FLAGS" CXXFLAGS="$OPT_FLAGS" \
%configure --prefix=%{_prefix} \
	--disable-dependency-tracking \
	--enable-cxx \
	--enable-fortran \
	--with-pthread \
	%ifarch x86_64
	--with-pic \
	%endif
	--enable-production=yes

%make_build

%if %{with tests}
%check
# all tests must pass on the following architectures
%ifarch %{ix86} x86_64
%__make check || echo "make check failed"
%else
%__make -k check || echo "make check failed"
%endif
%endif

%install
mkdir -p %{buildroot}%{_libdir}
%make_install
rm -f %{buildroot}%{_libdir}/*.la
%multiarch_includes %{buildroot}%{_includedir}/H5pubconf.h

%{__perl} -pi -e \
	"s@^libdir=\'/usr/lib\'@libdir=\'%{_libdir}\'@g" %{buildroot}%{_libdir}/*.la


# rpm macro for version checking
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/macros.hdf5 <<EOF
#
# RPM macros for R packaging
#

#
# Make R search index.txt
#
%_hdf5_version	%{version}
EOF

%files
%doc COPYING MANIFEST README.txt release_docs/RELEASE.txt
%{_bindir}/h5*
%{_bindir}/gif2*

%files -n %{libname}
%{_libdir}/libhdf5.so.%{major}{,.*}

%files -n %{libname_f}
%{_libdir}/libhdf5_fortran.so.%{major_f}{,.*}

%files -n %{libname_cpp}
%{_libdir}/libhdf5_cpp.so.%{major_cpp}{,.*}

%files -n %{libname_hl}
%{_libdir}/libhdf5_hl.so.%{major_hl}{,.*}

%files -n %{libname_hl_f}
%{_libdir}/libhdf5hl_fortran.so.%{major_hl_f}{,.*}

%files -n %{libname_hl_cpp}
%{_libdir}/libhdf5_hl_cpp.so.%{major_hl_cpp}{,.*}

%files -n %{develname}
%{_libdir}/*.a
%{_libdir}/*.so
%{_libdir}/*.settings
%{_includedir}/*
%{_datadir}/hdf5_examples/*
%config(noreplace) %{_sysconfdir}/rpm/macros.hdf5


%changelog
* Thu Jan 18 2024 daviddavid <daviddavid> 1.8.21-8.mga10
+ Revision: 2031939
- rebuild with shared libjpeg-devel

* Fri Mar 18 2022 umeabot <umeabot> 1.8.21-7.mga9
+ Revision: 1797737
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 1.8.21-6.mga8
+ Revision: 1523319
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Mar 03 2019 wally <wally> 1.8.21-5.mga7
+ Revision: 1371204
- split out all libs into their own pkgs

* Sat Mar 02 2019 wally <wally> 1.8.21-4.mga7
+ Revision: 1371087
- fix misnamed libs to properly handle updating from mga6
- drop unneeded conflicts
- add more stricter requires to devel pkg for libs

* Thu Feb 28 2019 daviddavid <daviddavid> 1.8.21-3.mga7
+ Revision: 1370500
- fix conflicts to ease upgrade mga6 -> mga7

* Sat Jan 05 2019 kekepower <kekepower> 1.8.21-2.mga7
+ Revision: 1349234
- Add patches from Fedora
- Remove wrong Provides that prevents the main package from getting installed

* Fri Jan 04 2019 zezinho <zezinho> 1.8.21-1.mga7
+ Revision: 1349127
- imported package hdf5_10

